@@ -7,5 +7,5 @@
 #'   abundance, species commonness, and spatial aggregation of conspecifics.
 #' 
 #' @name mobr
-#' @docType package
-NULL
\ No newline at end of file
+"_PACKAGE"
+
